ArrayField class final

Constructors

ArrayField({int? id, bool? nullable, bool ref = false, bool? dynamic, required TypeSpec element})
const

Properties

dynamic bool?
final
element TypeSpec
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
nullable bool?
final
ref bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited