Decimal class final

Exact decimal value represented as unscaledValue * 10^-scale.

Constructors

Decimal(BigInt unscaledValue, int scale)
Creates a decimal from its unscaled integer value and decimal scale.
const
Decimal.fromInt(int value, {int scale = 0})
Creates a decimal from a small integer value and optional scale.
factory
Decimal.zero([int scale = 0])
Creates a zero decimal with the given scale.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → int
The decimal scale.
final
unscaledValue → BigInt
The exact integer significand.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override