MapField class final

Constructors

MapField({int id = -1, bool? nullable, bool ref = false, bool? dynamic, TypeSpec? key, TypeSpec? value})
const

Properties

dynamic → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
key → TypeSpec?
final
nullable → bool?
final
ref → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TypeSpec?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited