Config class final
Fory instance configuration for the Dart xlang implementation.
The defaults favor compatible mode with conservative structural limits.
Constructors
- Config({bool compatible = true, bool checkStructVersion = true, int maxDepth = defaultMaxDepth, int maxTypeFields = defaultMaxTypeFields, int maxTypeMetaBytes = defaultMaxTypeMetaBytes, int maxSchemaVersionsPerType = defaultMaxSchemaVersionsPerType, int maxAverageSchemaVersionsPerType = defaultMaxAverageSchemaVersionsPerType, int maxGraphMemoryBytes = defaultMaxGraphMemoryBytes, int maxUnbackedContainerItems = defaultMaxUnbackedContainerItems})
- Creates an immutable configuration object.
Properties
- checkStructVersion → bool
-
Enables struct schema-version validation for same-schema payloads.
final
- compatible → bool
-
Enables compatible struct encoding and decoding.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAverageSchemaVersionsPerType → int
-
Maximum cached average remote metadata versions across logical
types.
final
- maxDepth → int
-
Maximum allowed read or write nesting depth.
final
- maxGraphMemoryBytes → int
-
Approximate graph-memory gate for one root deserialization.
final
- maxSchemaVersionsPerType → int
-
Maximum cached remote metadata versions for one logical type.
final
- maxTypeFields → int
-
Maximum accepted field count in one received struct TypeDef.
final
- maxTypeMetaBytes → int
-
Maximum accepted body size in one received TypeDef.
final
- maxUnbackedContainerItems → int
-
Maximum collection elements and map entries that may be read without
proportional input progress during one root deserialization.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultMaxAverageSchemaVersionsPerType → const int
- defaultMaxDepth → const int
- Default maximum nesting depth for a single serialization or deserialization operation.
- defaultMaxGraphMemoryBytes → const int
- defaultMaxSchemaVersionsPerType → const int
- defaultMaxTypeFields → const int
- defaultMaxTypeMetaBytes → const int
- defaultMaxUnbackedContainerItems → const int